dag_cbor.decoding
=================

.. automodule:: dag_cbor.decoding

DecodeCallback
--------------

.. autoclass:: dag_cbor.decoding.DecodeCallback
    :show-inheritance:
    :members:

decode
------

.. autofunction:: dag_cbor.decoding.decode

dag_cbor.decoding.__all__
-------------------------

The following members were explicitly reexported using ``__all__``:

    - :py:class:`dag_cbor.decoding.err.CBORDecodingError`
    - :py:class:`dag_cbor.decoding.err.DAGCBORDecodingError`
